#
# votca_tools.spec
#
# Copyright (c) 2013-2014 Christoph Junghans <junghans@votca.org>
#
# Originally written by Jussi Lehtola <jussilehtola@fedoraproject.org>
# Fixed for multi-distro build by Klaus Kaempf <kkaempf@suse.de>
#
# Licensed under the Apache Software License (ASL 2.0)
#

Name:           votca-tools
Version:        1.2.4
Release:        3.28
Summary:        VOTCA tools library
Group:          Productivity/Scientific/Chemistry
License:        Apache-2.0
URL:            http://www.votca.org
Source0:        http://downloads.votca.googlecode.com/hg/%{name}-%{version}_pristine.tar.gz

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  gcc-c++
%if %{defined fedora}
BuildRequires:  pkgconfig
BuildRequires:  expat-devel
%else
BuildRequires:  pkg-config
BuildRequires:  libexpat-devel
%endif
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  boost-devel  >= 1.39.0
BuildRequires:  cmake
BuildRequires:  txt2tags

%description
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package intended to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

%package -n libvotca_tools2
Summary:        VOTCA tools library
Group:          Productivity/Scientific/Chemistry

%description -n libvotca_tools2
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package intended to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains the basic tools library of VOTCA package.

%package devel
Summary:    Development headers and libraries for votca-tools
Group:      Development/Libraries/C and C++
Requires:   libvotca_tools2 = %{version}-%{release}

%description devel
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package intended to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains development headers and libraries for votca-tools.

%prep
%setup -q
# Get rid of bundled versions of boost and expat
rm -rf src/libboost
rm -rf src/libexpat

%build
%if %{defined fedora}
mkdir build
cd build
%endif
%if %{undefined cmake}
%define cmake cmake
mkdir build
cd build
%endif
%{cmake} \
 -DCMAKE_INSTALL_PREFIX=%{_prefix} \
 -DWITH_RC_FILES=OFF \
 -DCMAKE_VERBOSE_MAKEFILE=TRUE \
 -DCMAKE_C_FLAGS_RELEASE:STRING="%{optflags}" \
 -DCMAKE_CXX_FLAGS_RELEASE:STRING="%{optflags}" \
 -DCMAKE_BUILD_TYPE=Release \
 -DCMAKE_SKIP_RPATH=1 \
 -DLIB=%{_lib} ..
make %{?_smp_mflags}

%install
cd build
make install DESTDIR=%{buildroot}

%post -n libvotca_tools2 -p /sbin/ldconfig
%postun -n libvotca_tools2 -p /sbin/ldconfig

%files -n libvotca_tools2
%defattr(-,root,root,-)
%doc LICENSE NOTICE
%{_libdir}/libvotca_tools.so.*
%{_mandir}/man7/*
      
%files devel
%defattr(-,root,root,-)
%{_includedir}/votca/
%{_libdir}/libvotca_tools.so
%{_libdir}/pkgconfig/libvotca_tools.pc

%changelog
* Fri Sep  5 2014 junghans@votca.org
- Upgrade to 1.2.4
  * support for Boost 1.53
  * drop votca-tools-1.2.3-boost-1.53.patch: merged upstream
* Thu Nov 28 2013 junghans@votca.org
- implemented suggestions by mvyskocil from request 207986
* Fri Nov 22 2013 junghans@votca.org
- clean up suggested by saschpe in request 207134
* Wed Oct 30 2013 junghans@votca.org
- Upgrade to 1.2.3
  * rename package to libvotca_tools2
  * Add votca-tools-1.2.3-boost-1.53.patch: build with boost 1.53
  * create manpage using txt2tags
* Sun Aug 28 2011 kkaempf@suse.com
- Upgrade to 1.2.1
  * fixed soname of libs to .so.2
  - rename package to libvotca2
  * improved cmake checks and error messages
  * fixed pkg-config file
- Version 1.2 (SuperDoris)
  * changed buildsystem to cmake
  * added database class through sqlite3
- Version 1.1.2
  * fixed head of votca-tools manpage
* Thu Mar  3 2011 kkaempf@novell.com
- Upgrade to 1.1.1
  See http://code.google.com/p/votca/issues/list?can=1&q=Milestone%%3DRelease1.1
* Mon Dec  6 2010 kkaempf@novell.com
- Initial version 1.0.1 for openSUSE
- remove unused copies of boost and expat from tarball
  (incompatible license)
- fix packagename to follow shared lib name rule
  (incomplete, rpmlintrc added for override)
* Tue Nov 30 2010 junghans@votca.org
- Minor clean up
* Thu Nov 25 2010 jussilehtola@fedoraproject.org
- First release.
